@@ -1,6 +1,6 @@
 /* FunctionEditor.cpp
  *
- * Copyright (C) 1992-2023 Paul Boersma
+ * Copyright (C) 1992-2024 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -114,7 +114,7 @@ static void drawBackgroundAndData (FunctionEditor me) {
 	if (endIsVisible && my endSelection != my startSelection)
 		my marker [++ my numberOfMarkers] = my endSelection;
 	my marker [++ my numberOfMarkers] = my endWindow;
-	sort_VEC_inout (VEC (& my marker [1], my numberOfMarkers));
+	sort_e_VEC_inout (VEC (& my marker [1], my numberOfMarkers));
 
 	/*
 		Update rectangles.
@@ -1322,7 +1322,7 @@ static void gui_drawingarea_cb_expose (FunctionEditor me, GuiDrawingArea_ExposeE
 
 	/*
 		Not really drawing, but until further notice we believe that updating the menu items
-		(i.e. making them sensitive or insensitive) could be done as often as redrawing).
+		(i.e. making them sensitive or insensitive, or checking or unchecking them) could be done as often as redrawing.
 	*/
 	my v_updateMenuItems ();
 }
